@@ -1,10 +1,14 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
-import re
 import operator
+import re
+from six import text_type
 from datetime import datetime
+from functools import reduce
 
+from .compat import UnicodeMixin
 from .exceptions import ParsingException
 
 LOOKUPS = ['lte', 'gte', 'lt', 'gt', 'in', 'range', 'startswith', 'endswith']
@@ -12,7 +16,7 @@ LOOKUPS = ['lte', 'gte', 'lt', 'gt', 'in', 'range', 'startswith', 'endswith']
 LOOKUP_OPS = {'in': 'OR', 'range': 'TO'}
 
 
-class Query(object):
+class Query(UnicodeMixin):
 
     re_spaces = re.compile(r'\s+')
 
@@ -41,7 +45,7 @@ class Query(object):
         if query and field:
             msg = (
                 "You cannot use both words and fields in the same call. "
-                "You should do something like this: qb('{}') & {}"
+                "Instead, you can do something like this: qb('{}') & {}"
             ).format(query, fields_str)
             raise ParsingException(msg)
 
@@ -49,8 +53,8 @@ class Query(object):
         # object we also raise an exception
         if len(field) > 1:
             msg = (
-                "You cannot use more than one field the same call. "
-                "You should do something like this: {}"
+                "You cannot use more than one field in the same call. "
+                "Instead, you can do something like this: {}"
             ).format(fields_str)
             raise ParsingException(msg)
 
@@ -71,12 +75,12 @@ class Query(object):
         query = reduce(op, user_input)
         return query
 
-    def __str__(self):
+    def __unicode__(self):
         return self._cache or self._eval()
 
     def __and__(self, other):
         if self._empty:
-            self._cache = str(other)
+            self._cache = text_type(other)
         else:
             self._cache = '({} AND {})'.format(self, other)
         self._empty = False
@@ -84,7 +88,7 @@ class Query(object):
 
     def __or__(self, other):
         if self._empty:
-            self._cache = str(other)
+            self._cache = text_type(other)
         else:
             self._cache = '({} OR {})'.format(self, other)
         self._empty = False
@@ -95,7 +99,7 @@ class Query(object):
         return self
 
     def _process_field(self, field):
-        field, val = field.items()[0]
+        field, val = list(field.items())[0]
         lookup = None
         if '__' in field:
             field, lookup = field.rsplit('__', 1)
@@ -114,14 +118,14 @@ class Query(object):
             op = ' {} '.format(lookup and LOOKUP_OPS.get(lookup) or 'OR')
             return op.join(map(self._cast, val))
         if isinstance(val, Query):
-            return str(val)
+            return text_type(val)
 
         if lookup == 'startswith':
             val = '{}*'.format(val)
         elif lookup == 'endswith':
             val = '*{}'.format(val)
 
-        return '"{}"'.format(str(val))
+        return '"{}"'.format(val)
 
     def _process_lookup(self, lookup, value):
         if lookup == 'lte':
